@@ -14,7 +14,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.1203';
+our $VERSION = '0.1300';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -157,7 +157,7 @@ sub to_string
 
     return "Freecells:" . (($self->count() == 0) ? " " :
     join("",
-        map { "  " . (defined($_) ? $_->to_string() : "  ") }
+        map { "  " . (defined($_) ? $_->fast_s() : "  ") }
         map { $self->cell($_) }
         (0 .. ($self->count()-1))
     ));
